# rpl

A search/replace utility.

rpl replaces strings with new strings in multiple text files.

rpl is distributed under the terms of the GNU General Public License; either
version 3 of the License, or (at your option), any later version. See the
file COPYING for more details.
